pub enum ApiError {
Show 16 variants
IpBanned,
NotLoggedIn,
TorrentNotFound,
TorrentNameEmpty,
TorrentFileInvalid,
InvalidTrackerUrl,
ConflictTrackerUrl,
InvalidPeers,
QueueingDisabled,
MetaNotDownloadedOrIdNotFound,
SavePathEmpty,
NoWriteAccess,
UnableToCreateDir,
CategoryNotFound,
CategoryEditingFailed,
InvalidPath,
}Expand description
Errors defined and returned by the API
Variants
IpBanned
User’s IP is banned for too many failed login attempts
NotLoggedIn
API routes requires login, try again
TorrentNotFound
Torrent not found
TorrentNameEmpty
Torrent name is empty
TorrentFileInvalid
Torrent file is not valid
InvalidTrackerUrl
newUrl is not a valid URL
ConflictTrackerUrl
newUrl already exists for the torrent or origUrl was not found
InvalidPeers
None of the given peers are valid
QueueingDisabled
Torrent queueing is not enabled
MetaNotDownloadedOrIdNotFound
Torrent metadata hasn’t downloaded yet or at least one file id was not found
SavePathEmpty
Save path is empty
NoWriteAccess
User does not have write access to the directory
UnableToCreateDir
Unable to create save path directory
CategoryNotFound
Category name does not exist
CategoryEditingFailed
Category editing failed
InvalidPath
Invalid newPath or oldPath, or newPath already in use