pub enum ContentLayout {
Original,
Subfolder,
NoSubfolder,
}Expand description
How the files of a torrent are laid out on disk when added.
Variants
Original
Use the layout as defined by the torrent itself.
Subfolder
Always create a subfolder containing the torrent’s files.
NoSubfolder
Never create a subfolder, placing files directly in the save path.