pub struct Tracker {
pub url: String,
pub status: TrackerStatus,
pub tier: i64,
pub num_peers: i64,
pub num_seeds: i64,
pub num_leeches: i64,
pub num_downloaded: i64,
pub msg: String,
pub next_announce: i64,
pub min_announce: i64,
}Fields
url: StringTracker url
status: TrackerStatusTracker status. See the table below for possible values
tier: i64Tracker priority tier. Lower tier trackers are tried before higher
tiers. Tier numbers are valid when >= 0, < 0 is used as placeholder
when tier does not exist for special entries (such as DHT).
num_peers: i64Number of peers for current torrent, as reported by the tracker
num_seeds: i64Number of seeds for current torrent, as reported by the tracker
num_leeches: i64Number of leeches for current torrent, as reported by the tracker
num_downloaded: i64Number of completed downloads for current torrent, as reported by the tracker
msg: StringTracker message (there is no way of knowing what this message is - it’s up to tracker admins)
next_announce: i64Next announce timestamp (added in qBittorrent 5.2.0, Web API v2.13.0)
min_announce: i64Minimum announce interval in seconds (added in qBittorrent 5.2.0, Web API v2.13.0)