pub struct Qbit { /* private fields */ }Expand description
Main entry point of the library. It provides a high-level API to interact with qBittorrent WebUI API.
Implementations
Sourceimpl Qbit
impl Qbit
Sourcepub async fn get_version(&self) -> Result<String, Error>
pub async fn get_version(&self) -> Result<String, Error>
Return the qBittorrent application version.
Sourcepub async fn get_webapi_version(&self) -> Result<String, Error>
pub async fn get_webapi_version(&self) -> Result<String, Error>
Return the qBittorrent Web API version.
Sourcepub async fn get_build_info(&self) -> Result<BuildInfo, Error>
pub async fn get_build_info(&self) -> Result<BuildInfo, Error>
Return qBittorrent build information and dependency versions.
Sourcepub async fn get_process_info(&self) -> Result<ProcessInfo, Error>
pub async fn get_process_info(&self) -> Result<ProcessInfo, Error>
Get process info, including launch time.
Added in qBittorrent 5.2.0 (Web API v2.15.1).
Get cookies stored in the qBittorrent WebUI.
Added in qBittorrent 5.2.0 (Web API v2.11.3).
Set cookies for the qBittorrent WebUI.
Added in qBittorrent 5.2.0 (Web API v2.11.3).
Sourcepub async fn get_preferences(&self) -> Result<Preferences, Error>
pub async fn get_preferences(&self) -> Result<Preferences, Error>
Return the application preferences.
Sourcepub async fn set_preferences(
&self,
preferences: impl Borrow<Preferences> + Send + Sync,
) -> Result<(), Error>
pub async fn set_preferences( &self, preferences: impl Borrow<Preferences> + Send + Sync, ) -> Result<(), Error>
Update the supplied application preferences.
Sourcepub async fn get_free_space_at_path(
&self,
path: impl AsRef<Path> + Send + Sync,
) -> Result<u64, Error>
pub async fn get_free_space_at_path( &self, path: impl AsRef<Path> + Send + Sync, ) -> Result<u64, Error>
Get free disk space at the given path (in bytes).
Added in qBittorrent 5.2.0 (Web API v2.15.2).
Sourcepub async fn get_default_save_path(&self) -> Result<PathBuf, Error>
pub async fn get_default_save_path(&self) -> Result<PathBuf, Error>
Return the default path used to save torrent content.
Sourceimpl Qbit
impl Qbit
Sourceimpl Qbit
impl Qbit
Sourcepub async fn add_folder<T: AsRef<str> + Send + Sync>(
&self,
path: T,
) -> Result<(), Error>
pub async fn add_folder<T: AsRef<str> + Send + Sync>( &self, path: T, ) -> Result<(), Error>
Add a folder to the RSS hierarchy.
Sourcepub async fn add_feed<T: AsRef<str> + Send + Sync>(
&self,
url: T,
path: Option<T>,
) -> Result<(), Error>
pub async fn add_feed<T: AsRef<str> + Send + Sync>( &self, url: T, path: Option<T>, ) -> Result<(), Error>
Add an RSS feed, optionally under the supplied folder.
Sourcepub async fn remove_item<T: AsRef<str> + Send + Sync>(
&self,
path: T,
) -> Result<(), Error>
pub async fn remove_item<T: AsRef<str> + Send + Sync>( &self, path: T, ) -> Result<(), Error>
Remove an RSS feed or folder.
Sourcepub async fn move_item<T: AsRef<str> + Send + Sync>(
&self,
item_path: T,
dest_path: T,
) -> Result<(), Error>
pub async fn move_item<T: AsRef<str> + Send + Sync>( &self, item_path: T, dest_path: T, ) -> Result<(), Error>
Move an RSS feed or folder to another path.
Sourcepub async fn mark_as_read<T: AsRef<str> + Send + Sync>(
&self,
item_path: T,
article_id: Option<T>,
) -> Result<(), Error>
pub async fn mark_as_read<T: AsRef<str> + Send + Sync>( &self, item_path: T, article_id: Option<T>, ) -> Result<(), Error>
Mark an RSS item or article as read.
Sourcepub async fn refresh_item<T: AsRef<str> + Send + Sync>(
&self,
item_path: T,
) -> Result<(), Error>
pub async fn refresh_item<T: AsRef<str> + Send + Sync>( &self, item_path: T, ) -> Result<(), Error>
Refresh an RSS feed or folder.
Sourceimpl Qbit
impl Qbit
Sourceimpl Qbit
impl Qbit
Sourcepub async fn get_torrent_list(
&self,
arg: GetTorrentListArg,
) -> Result<Vec<Torrent>, Error>
pub async fn get_torrent_list( &self, arg: GetTorrentListArg, ) -> Result<Vec<Torrent>, Error>
Return torrents matching the supplied filters and pagination options.
Sourcepub async fn export_torrent(
&self,
hash: impl AsRef<str> + Send + Sync,
) -> Result<Bytes, Error>
pub async fn export_torrent( &self, hash: impl AsRef<str> + Send + Sync, ) -> Result<Bytes, Error>
Export the torrent metadata file for the supplied hash.
Sourcepub async fn download_torrent_file(
&self,
hash: impl AsRef<str> + Send + Sync,
file: impl AsRef<str> + Send + Sync,
) -> Result<Bytes, Error>
pub async fn download_torrent_file( &self, hash: impl AsRef<str> + Send + Sync, file: impl AsRef<str> + Send + Sync, ) -> Result<Bytes, Error>
Download a completed file from a torrent’s content.
file can be either a file index (as a number) or a path relative
to the torrent content root.
Added in qBittorrent 5.2.0 (Web API v2.16.0).
Sourcepub async fn get_torrent_properties(
&self,
hash: impl AsRef<str> + Send + Sync,
) -> Result<TorrentProperty, Error>
pub async fn get_torrent_properties( &self, hash: impl AsRef<str> + Send + Sync, ) -> Result<TorrentProperty, Error>
Return generic properties for the supplied torrent.
Sourcepub async fn get_torrent_piece_availability(
&self,
hash: impl AsRef<str> + Send + Sync,
) -> Result<Vec<i64>, Error>
pub async fn get_torrent_piece_availability( &self, hash: impl AsRef<str> + Send + Sync, ) -> Result<Vec<i64>, Error>
Get the availability (number of distributed copies) of each piece of a torrent. Returns a vector where each element is the availability count for the corresponding piece index.
Added in qBittorrent 5.2.0 (Web API v2.15.1).
Sourcepub async fn get_torrent_trackers(
&self,
hash: impl AsRef<str> + Send + Sync,
) -> Result<Vec<Tracker>, Error>
pub async fn get_torrent_trackers( &self, hash: impl AsRef<str> + Send + Sync, ) -> Result<Vec<Tracker>, Error>
Return trackers for the supplied torrent.
Sourcepub async fn get_torrent_web_seeds(
&self,
hash: impl AsRef<str> + Send + Sync,
) -> Result<Vec<WebSeed>, Error>
pub async fn get_torrent_web_seeds( &self, hash: impl AsRef<str> + Send + Sync, ) -> Result<Vec<WebSeed>, Error>
Return web seeds for the supplied torrent.
Sourcepub async fn get_torrent_contents(
&self,
hash: impl AsRef<str> + Send + Sync,
indexes: impl Into<Option<Sep<String, '|'>>> + Send + Sync,
) -> Result<Vec<TorrentContent>, Error>
pub async fn get_torrent_contents( &self, hash: impl AsRef<str> + Send + Sync, indexes: impl Into<Option<Sep<String, '|'>>> + Send + Sync, ) -> Result<Vec<TorrentContent>, Error>
Return file content information for the supplied torrent.
Sourcepub async fn get_torrent_pieces_states(
&self,
hash: impl AsRef<str> + Send + Sync,
) -> Result<Vec<PieceState>, Error>
pub async fn get_torrent_pieces_states( &self, hash: impl AsRef<str> + Send + Sync, ) -> Result<Vec<PieceState>, Error>
Return the download state of each piece in the supplied torrent.
Sourcepub async fn get_torrent_pieces_hashes(
&self,
hash: impl AsRef<str> + Send + Sync,
) -> Result<Vec<String>, Error>
pub async fn get_torrent_pieces_hashes( &self, hash: impl AsRef<str> + Send + Sync, ) -> Result<Vec<String>, Error>
Return the hash of each piece in the supplied torrent.
Sourcepub async fn stop_torrents(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn stop_torrents( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Stop the supplied torrents.
Sourcepub async fn start_torrents(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn start_torrents( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Start the supplied torrents.
Sourcepub async fn delete_torrents(
&self,
hashes: impl Into<Hashes> + Send + Sync,
delete_files: impl Into<Option<bool>> + Send + Sync,
) -> Result<(), Error>
pub async fn delete_torrents( &self, hashes: impl Into<Hashes> + Send + Sync, delete_files: impl Into<Option<bool>> + Send + Sync, ) -> Result<(), Error>
Delete the supplied torrents, optionally including their downloaded files.
Sourcepub async fn recheck_torrents(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn recheck_torrents( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Recheck the supplied torrents against their downloaded data.
Sourcepub async fn reannounce_torrents(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn reannounce_torrents( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Reannounce the supplied torrents to their trackers.
Sourcepub async fn reannounce_torrents_with_trackers(
&self,
hashes: impl Into<Hashes> + Send + Sync,
trackers: impl Into<Sep<String, '|'>> + Send + Sync,
) -> Result<(), Error>
pub async fn reannounce_torrents_with_trackers( &self, hashes: impl Into<Hashes> + Send + Sync, trackers: impl Into<Sep<String, '|'>> + Send + Sync, ) -> Result<(), Error>
Reannounce torrents, optionally specifying which trackers to contact.
trackers is a pipe-separated list of tracker URLs. Added in
qBittorrent 5.2.0 (Web API v2.11.10).
Sourcepub async fn add_torrent(
&self,
arg: impl Borrow<AddTorrentArg> + Send + Sync,
) -> Result<(), Error>
pub async fn add_torrent( &self, arg: impl Borrow<AddTorrentArg> + Send + Sync, ) -> Result<(), Error>
Add one or more torrents from URLs or torrent files.
Sourcepub async fn add_trackers(
&self,
hash: impl AsRef<str> + Send + Sync,
urls: impl Into<Sep<String, '\n'>> + Send + Sync,
) -> Result<(), Error>
pub async fn add_trackers( &self, hash: impl AsRef<str> + Send + Sync, urls: impl Into<Sep<String, '\n'>> + Send + Sync, ) -> Result<(), Error>
Add trackers to the supplied torrent.
Sourcepub async fn edit_trackers(
&self,
hash: impl AsRef<str> + Send + Sync,
orig_url: Url,
new_url: Url,
) -> Result<(), Error>
pub async fn edit_trackers( &self, hash: impl AsRef<str> + Send + Sync, orig_url: Url, new_url: Url, ) -> Result<(), Error>
Replace a tracker URL on the supplied torrent.
Sourcepub async fn remove_trackers(
&self,
hash: impl AsRef<str> + Send + Sync,
urls: impl Into<Sep<Url, '|'>> + Send + Sync,
) -> Result<(), Error>
pub async fn remove_trackers( &self, hash: impl AsRef<str> + Send + Sync, urls: impl Into<Sep<Url, '|'>> + Send + Sync, ) -> Result<(), Error>
Remove trackers from the supplied torrent.
Sourcepub async fn add_peers(
&self,
hashes: impl Into<Hashes> + Send + Sync,
peers: impl Into<Sep<String, '|'>> + Send + Sync,
) -> Result<(), Error>
pub async fn add_peers( &self, hashes: impl Into<Hashes> + Send + Sync, peers: impl Into<Sep<String, '|'>> + Send + Sync, ) -> Result<(), Error>
Add peers to the supplied torrents.
Sourcepub async fn increase_priority(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn increase_priority( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Increase the queue priority of the supplied torrents.
Sourcepub async fn decrease_priority(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn decrease_priority( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Decrease the queue priority of the supplied torrents.
Sourcepub async fn maximal_priority(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn maximal_priority( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Move the supplied torrents to the top of the queue.
Sourcepub async fn minimal_priority(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn minimal_priority( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Move the supplied torrents to the bottom of the queue.
Sourcepub async fn set_file_priority(
&self,
hash: impl AsRef<str> + Send + Sync,
indexes: impl Into<Sep<i64, '|'>> + Send + Sync,
priority: Priority,
) -> Result<(), Error>
pub async fn set_file_priority( &self, hash: impl AsRef<str> + Send + Sync, indexes: impl Into<Sep<i64, '|'>> + Send + Sync, priority: Priority, ) -> Result<(), Error>
Set the download priority of selected files in a torrent.
Sourcepub async fn get_torrent_download_limit(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<HashMap<String, u64>, Error>
pub async fn get_torrent_download_limit( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<HashMap<String, u64>, Error>
Return the download limit for the supplied torrent.
Sourcepub async fn set_torrent_download_limit(
&self,
hashes: impl Into<Hashes> + Send + Sync,
limit: u64,
) -> Result<(), Error>
pub async fn set_torrent_download_limit( &self, hashes: impl Into<Hashes> + Send + Sync, limit: u64, ) -> Result<(), Error>
Set the download limit for the supplied torrents.
Set share-ratio and seeding-time limits for the supplied torrents.
Sourcepub async fn get_torrent_upload_limit(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<HashMap<String, u64>, Error>
pub async fn get_torrent_upload_limit( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<HashMap<String, u64>, Error>
Return the upload limit for the supplied torrent.
Sourcepub async fn set_torrent_upload_limit(
&self,
hashes: impl Into<Hashes> + Send + Sync,
limit: u64,
) -> Result<(), Error>
pub async fn set_torrent_upload_limit( &self, hashes: impl Into<Hashes> + Send + Sync, limit: u64, ) -> Result<(), Error>
Set the upload limit for the supplied torrents.
Sourcepub async fn set_torrent_location(
&self,
hashes: impl Into<Hashes> + Send + Sync,
location: impl AsRef<Path> + Send + Sync,
) -> Result<(), Error>
pub async fn set_torrent_location( &self, hashes: impl Into<Hashes> + Send + Sync, location: impl AsRef<Path> + Send + Sync, ) -> Result<(), Error>
Set the save location for the supplied torrents.
Sourcepub async fn set_torrent_name<T: AsRef<str> + Send + Sync>(
&self,
hash: impl AsRef<str> + Send + Sync,
name: NonEmptyStr<T>,
) -> Result<(), Error>
pub async fn set_torrent_name<T: AsRef<str> + Send + Sync>( &self, hash: impl AsRef<str> + Send + Sync, name: NonEmptyStr<T>, ) -> Result<(), Error>
Rename the supplied torrent.
Sourcepub async fn set_torrent_comment(
&self,
hashes: impl Into<Hashes> + Send + Sync,
comment: &str,
) -> Result<(), Error>
pub async fn set_torrent_comment( &self, hashes: impl Into<Hashes> + Send + Sync, comment: &str, ) -> Result<(), Error>
Set the comment for one or more torrents.
Added in qBittorrent 5.2.0 (Web API v2.12.1).
Sourcepub async fn set_torrent_category(
&self,
hashes: impl Into<Hashes> + Send + Sync,
category: impl AsRef<str> + Send + Sync,
) -> Result<(), Error>
pub async fn set_torrent_category( &self, hashes: impl Into<Hashes> + Send + Sync, category: impl AsRef<str> + Send + Sync, ) -> Result<(), Error>
Set the category of the supplied torrents.
Sourcepub async fn get_categories(&self) -> Result<HashMap<String, Category>, Error>
pub async fn get_categories(&self) -> Result<HashMap<String, Category>, Error>
Return all torrent categories.
Sourcepub async fn add_category<T: AsRef<str> + Send + Sync>(
&self,
category: NonEmptyStr<T>,
save_path: impl AsRef<Path> + Send + Sync,
) -> Result<(), Error>
pub async fn add_category<T: AsRef<str> + Send + Sync>( &self, category: NonEmptyStr<T>, save_path: impl AsRef<Path> + Send + Sync, ) -> Result<(), Error>
Create a torrent category with the supplied save path.
Sourcepub async fn edit_category<T: AsRef<str> + Send + Sync>(
&self,
category: NonEmptyStr<T>,
save_path: impl AsRef<Path> + Send + Sync,
) -> Result<(), Error>
pub async fn edit_category<T: AsRef<str> + Send + Sync>( &self, category: NonEmptyStr<T>, save_path: impl AsRef<Path> + Send + Sync, ) -> Result<(), Error>
Update the save path of a torrent category.
Sourcepub async fn remove_categories(
&self,
categories: impl Into<Sep<String, '\n'>> + Send + Sync,
) -> Result<(), Error>
pub async fn remove_categories( &self, categories: impl Into<Sep<String, '\n'>> + Send + Sync, ) -> Result<(), Error>
Remove the supplied torrent categories.
Add tags to the supplied torrents.
Remove tags from the supplied torrents.
Return all torrent tags.
Create the supplied torrent tags.
Delete the supplied torrent tags.
Sourcepub async fn set_auto_management(
&self,
hashes: impl Into<Hashes> + Send + Sync,
enable: bool,
) -> Result<(), Error>
pub async fn set_auto_management( &self, hashes: impl Into<Hashes> + Send + Sync, enable: bool, ) -> Result<(), Error>
Enable or disable automatic torrent management for the supplied torrents.
Sourcepub async fn toggle_sequential_download(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn toggle_sequential_download( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Toggle sequential downloading for the supplied torrents.
Sourcepub async fn toggle_first_last_piece_priority(
&self,
hashes: impl Into<Hashes> + Send + Sync,
) -> Result<(), Error>
pub async fn toggle_first_last_piece_priority( &self, hashes: impl Into<Hashes> + Send + Sync, ) -> Result<(), Error>
Toggle first and last piece priority for the supplied torrents.
Sourcepub async fn set_force_start(
&self,
hashes: impl Into<Hashes> + Send + Sync,
value: bool,
) -> Result<(), Error>
pub async fn set_force_start( &self, hashes: impl Into<Hashes> + Send + Sync, value: bool, ) -> Result<(), Error>
Enable or disable force start for the supplied torrents.
Sourcepub async fn set_super_seeding(
&self,
hashes: impl Into<Hashes> + Send + Sync,
value: bool,
) -> Result<(), Error>
pub async fn set_super_seeding( &self, hashes: impl Into<Hashes> + Send + Sync, value: bool, ) -> Result<(), Error>
Enable or disable super seeding for the supplied torrents.
Sourceimpl Qbit
impl Qbit
Sourcepub async fn get_transfer_info(&self) -> Result<TransferInfo, Error>
pub async fn get_transfer_info(&self) -> Result<TransferInfo, Error>
Return the global transfer information shown in the qBittorrent status bar.
Sourcepub async fn get_speed_limits_mode(&self) -> Result<bool, Error>
pub async fn get_speed_limits_mode(&self) -> Result<bool, Error>
Return whether alternative speed limits are enabled.
Sourcepub async fn toggle_speed_limits_mode(&self) -> Result<(), Error>
pub async fn toggle_speed_limits_mode(&self) -> Result<(), Error>
Toggle alternative speed limits.
Sourcepub async fn get_speed_limits(&self) -> Result<SpeedLimits, Error>
pub async fn get_speed_limits(&self) -> Result<SpeedLimits, Error>
Get global and alternative speed limits (KiB/s, -1 = unlimited).
Added in qBittorrent 5.2.0 (Web API v2.16.0).
Sourcepub async fn set_speed_limits(&self, limits: &SpeedLimits) -> Result<(), Error>
pub async fn set_speed_limits(&self, limits: &SpeedLimits) -> Result<(), Error>
Set global and alternative speed limits (KiB/s, -1 = unlimited).
Added in qBittorrent 5.2.0 (Web API v2.16.0).
Sourcepub async fn get_download_limit(&self) -> Result<u64, Error>
pub async fn get_download_limit(&self) -> Result<u64, Error>
Return the global download limit in bytes per second.
Sourcepub async fn set_download_limit(&self, limit: u64) -> Result<(), Error>
pub async fn set_download_limit(&self, limit: u64) -> Result<(), Error>
Set the global download limit in bytes per second.
Sourcepub async fn get_upload_limit(&self) -> Result<u64, Error>
pub async fn get_upload_limit(&self) -> Result<u64, Error>
Return the global upload limit in bytes per second.
Sourceimpl Qbit
impl Qbit
Sourcepub fn builder() -> QbitBuilder
pub fn builder() -> QbitBuilder
Create a new QbitBuilder to build a Qbit instance.
pub fn new_with_client<U>( endpoint: U, credential: Credential, client: Client, ) -> Self
pub fn new<U>(endpoint: U, credential: Credential) -> Self